summaryrefslogtreecommitdiffstats
path: root/pym
diff options
context:
space:
mode:
authorZac Medico <zmedico@gentoo.org>2006-10-21 23:40:13 +0000
committerZac Medico <zmedico@gentoo.org>2006-10-21 23:40:13 +0000
commit8829466443c5bb58cc180331ae5586c94eef36d4 (patch)
treeaad5c60c5550cca49ca0e08c9546624b63f95e18 /pym
parent320ede8e57fbf29f8e13172a909655b64beeca8c (diff)
downloadportage-8829466443c5bb58cc180331ae5586c94eef36d4.tar.gz
portage-8829466443c5bb58cc180331ae5586c94eef36d4.tar.bz2
portage-8829466443c5bb58cc180331ae5586c94eef36d4.zip
Use reset instead of regenerate (revert part of the previous commit) in order to properly clear the env layer of the config.
svn path=/main/trunk/; revision=4787
Diffstat (limited to 'pym')
-rw-r--r--pym/portage.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/pym/portage.py b/pym/portage.py
index 5f5310715..86a998c64 100644
--- a/pym/portage.py
+++ b/pym/portage.py
@@ -2588,12 +2588,12 @@ def doebuild_environment(myebuild, mydo, myroot, mysettings, debug, use_cache, m
"Invalid ebuild path: '%s'" % myebuild)
if mydo != "depend":
- mysettings.setcpv(mycpv, use_cache=use_cache, mydb=mydbapi)
- """For performance reasons, setcpv only triggers regenerate when it
+ """For performance reasons, setcpv only triggers reset when it
detects a package-specific change in config. For the ebuild
environment, a regenerate call is forced in order to ensure that the
latest env.d variables are used."""
- mysettings.regenerate()
+ mysettings.reset(use_cache=use_cache)
+ mysettings.setcpv(mycpv, use_cache=use_cache, mydb=mydbapi)
mysettings["EBUILD_PHASE"] = mydo
@@ -2588,12 +2588,12 @@ def doebuild_environment(myebuild, mydo, myroot, mysettings, debug, use_cache, m
detects a package-specific change in config. For the ebuild
- environment, a regenerate call is forced in order to ensure that the
+ environment, a reset call is forced in order to ensure that the
latest env.d variables are used."""